# shameni
The official Presage Python wrapper, a straightforward cryptocurrency prediction service.

Powered by [CoinGecko](https://www.coingecko.com/api/documentations/v3) and [Presage](http://presage.herokuapp.com/) API.

**DISCLAIMER:** All data generated by Presage and/or Shameni does not indicate real cryptocurrency prices and does not constitute to an expert financial advice. Do your own research and only take financial advice from a certified financial expert. This website and the information contained herein is not intended to be a source of any financial advice with respect to the material presented, and the information and/or documents contained in this website do not constitute investment advice.

## Usage
**Installation**
```python
pip install --upgrade shameni
```

**Import Package**
```python
from shameni import Gaze
```

**Initialization**
```python
# simple initialization
crypto = Gaze()

# cache data to file
crypto = Gaze("predictions.json")
```

**Check connection**
```python
if crypto.ping():
    print("Live!")
```

**Supported tokens**
```python
for token in crypto.supported():
    print(token)
```

**Actual Price**
Returns the actual cryptocurrency price
```python
price = crypto.price("bitcoin")
```

**Weighted Average**
Returns the periodic WAVGs
```python
# days = 1, 3, 7, 15, 30, 60, 90
wavg = crypto.wavg("bitcoin", 3)
```

**Request**
Requests for next-day prediction.
```python
crypto.request("bitcoin")
```

**Prediction**
Returns the available next-day prediction.
```python
    tomorrow = crypto.tomorrow("bitcoin")
    if tomorrow > 0:
        print(f" - Tomorrow: {tomorrow:,.2f} USD")
```

**Distance**
Returns the historical distance between the atcual price and predictions.
```python
gap = crypto.distance("bitcoin")
if gap > 0:
    print(f" - Distance: {gap:,.6f}")
```